@@ -29,6 +29,7 @@ class Settings(YamlBasedSettings):
     JSON_LOG_FILE: str | None = None
     LOG_AS_JSON: bool = False
     EXPOSE_PII: bool = False
+    ENVIORNMENT_NAME: str = "DEV"
 
     # API key
     API_KEY: str | None = None
@@ -57,8 +58,9 @@ class Settings(YamlBasedSettings):
     OPENTELEMETRY_ENABLE: bool = False
     OPENTELEMETRY_COMPONENT_NAME: str = "superlinked-server"
     OPENTELEMETRY_PROJECT_ID: str | None = None
-    OPENTELEMETRY_EXPORT_INTERVAL_IN_MS: int = 10000
+    OPENTELEMETRY_EXPORT_INTERVAL_IN_MS: int = 30000
     OPENTELEMETRY_TRACE_SAMPLING_RATE: float = 1.0
+    OPENTELEMETRY_RETRY_MAX_ATTEMPTS: int = 5
 
     model_config = SettingsConfigDict(
         yaml_file=YAML_FILENAME, yaml_config_section=SERVER_SECTION, extra="ignore", frozen=True
