@@ -20,7 +20,6 @@ import structlog
 from fastapi import Depends, FastAPI, status
 
 from superlinked.framework.common.util.class_helper import ClassHelper
-from superlinked.framework.common.util.execution_timer import ExecutionTimer
 from superlinked.framework.dsl.app.rest.rest_app import RestApp
 from superlinked.framework.dsl.executor.rest.rest_executor import RestExecutor
 from superlinked.framework.dsl.index.index import Index
@@ -63,7 +62,6 @@ def teardown_application(_: FastAPI) -> None:
     persistence_service: PersistenceService = inject.instance(PersistenceService)
     logger.info("shutdown event detected")
     persistence_service.persist()
-    ExecutionTimer.flush()
 
 
 def _setup_executors(
